=========
Changelog
=========

v0.2.0 (2021-11-30)
===================
Features
--------
- Added official support for CPython 3.7 and CPython 3.8
- Added official support for MacOS and Windows
- Added official support for Neovim

Fixes
-----
- rst-ls no longer crashes when started without a log file


v0.1.0 (2021-11-26)
===================
Initial release with support for completion of title adornments in Kate
